@@ -1,7 +1,7 @@
 import os
 import torch
 
-from s3prl.utility.download import _urls_to_filepaths
+from s3prl.util.download import _urls_to_filepaths
 from .upstream_expert import UpstreamExpert as _UpstreamExpert
 
 
@@ -27,5 +27,5 @@ def timit_posteriorgram(refresh=False, *args, **kwargs):
         The default model
             refresh (bool): whether to download ckpt/config again if existed
     """
-    kwargs['ckpt'] = 'https://www.dropbox.com/s/fb2hkvetp26wges/convbank.ckpt?dl=0'
+    kwargs['ckpt'] = 'https://www.dropbox.com/s/fb2hkvetp26wges/convbank.ckpt?dl=1'
     return timit_posteriorgram_url(refresh=refresh, *args, **kwargs)
